==> diamond-shop-v1.3.50-043668.zip: src/DTO/OrderItemRequest.php <==
<?

namespace Shop\DTO;

/**
 * Description of OrderItemRequest
 *
 * @author Admin
 */
class OrderItemRequest
{

    protected $name;
    protected $article;
    protected $price;
    protected $brand;
    protected $desc;
    protected $amount;
    protected $managerComment;
    protected $MenagerComment;
    protected $refId;
    protected $currencyId;
    
    function getCurrencyId()
    {
        return $this->currencyId;
    }

    function setCurrencyId($currencyId)
    {
        $this->currencyId = $currencyId;
        return $this;
    }
    
    function getRefId()
    {
        return $this->refId;
    }

    function setRefId($refId)
    {
        $this->refId = $refId;
        return $this;
    }
            
    function getMenagerComment()
    {
        return $this->MenagerComment;
    }

    function setMenagerComment($MenagerComment)
    {
        $this->MenagerComment = $MenagerComment;
        return $this;
    }

        
    function getName()
    {
        return $this->name;
    }

    function getArticle()
    {
        return $this->article;
    }

    function getPrice()
    {
        return $this->price;
    }

    function getBrand()
    {
        return $this->brand;
    }

    function getDesc()
    {
        return $this->desc;
    }

    function getAmount()
    {
        return $this->amount;
    }

    function getManagerComment()
    {
        return $this->managerComment;
    }

    function setName($name)
    {
        $this->name = $name;
        return $this;
    }

    function setArticle($article)
    {
        $this->article = $article;
        return $this;
    }

    function setPrice($price)
    {
        $this->price = $price;
        return $this;
    }

    function setBrand($brand)
    {
        $this->brand = $brand;
        return $this;
    }

    function setDesc($desc)
    {
        $this->desc = $desc;
        return $this;
    }

    function setAmount($amount)
    {
        $this->amount = $amount;
        return $this;
    }

    function setManagerComment($managerComment)
    {
        $this->managerComment = $managerComment;
        return $this;
    }

}

==> diamond-shop-v1.4.14-99a1b7.zip: src/DTO/OrderItemRequest.php <==
<?

namespace Shop\DTO;

/**
 * Description of OrderItemRequest
 *
 * @author Admin
 */
class OrderItemRequest
{

    protected $name;
    protected $article;
    protected $price;
    protected $brand;
    protected $desc;
    protected $amount;
    protected $managerComment;
    protected $MenagerComment;
    protected $refId;
    protected $currencyId;
    /**
     * @var string
     */
    protected $destination;

    /**
     * @return string
     */
    public function getDestination(): ?string
    {
        return $this->destination;
    }

    /**
     * @param string $destination
     * @return OrderItemRequest
     */
    public function setDestination(?string $destination): OrderItemRequest
    {
        $this->destination = $destination;
        return $this;
    }
    
    function getCurrencyId()
    {
        return $this->currencyId;
    }

    function setCurrencyId($currencyId)
    {
        $this->currencyId = $currencyId;
        return $this;
    }
    
    function getRefId()
    {
        return $this->refId;
    }

    function setRefId($refId)
    {
        $this->refId = $refId;
        return $this;
    }
            
    function getMenagerComment()
    {
        return $this->MenagerComment;
    }

    function setMenagerComment($MenagerComment)
    {
        $this->MenagerComment = $MenagerComment;
        return $this;
    }

        
    function getName()
    {
        return $this->name;
    }

    function getArticle()
    {
        return $this->article;
    }

    function getPrice()
    {
        return $this->price;
    }

    function getBrand()
    {
        return $this->brand;
    }

    function getDesc()
    {
        return $this->desc;
    }

    function getAmount()
    {
        return $this->amount;
    }

    function getManagerComment()
    {
        return $this->managerComment;
    }

    function setName($name)
    {
        $this->name = $name;
        return $this;
    }

    function setArticle($article)
    {
        $this->article = $article;
        return $this;
    }

    function setPrice($price)
    {
        $this->price = $price;
        return $this;
    }

    function setBrand($brand)
    {
        $this->brand = $brand;
        return $this;
    }

    function setDesc($desc)
    {
        $this->desc = $desc;
        return $this;
    }

    function setAmount($amount)
    {
        $this->amount = $amount;
        return $this;
    }

    function setManagerComment($managerComment)
    {
        $this->managerComment = $managerComment;
        return $this;
    }

}
